@@ -38,15 +38,17 @@
 
 #define QT_FEATURE_pulseaudio 1
 
-#define QT_FEATURE_wmsdk -1
-
 #define QT_FEATURE_opensles -1
 
 #define QT_FEATURE_wasm -1
 
+#define QT_FEATURE_wasapi -1
+
 #define QT_FEATURE_wmf -1
 
 #define QT_FEATURE_spatialaudio 1
 
 #define QT_FEATURE_spatialaudio_quick3d 1
 
+#define QT_FEATURE_ffmpeg_stubs -1
+
